==> tuia-advert-center-api-2.3.47-sources.jar: cn/com/duiba/tuia/core/api/dto/flowback/MsgDataFlowbackPlanDTO.java <==
package cn.com.duiba.tuia.core.api.dto.flowback;

import java.util.List;

public class MsgDataFlowbackPlanDTO {
    private Long planId;

    private Long advertId;

    private Long appId;

    private String appKey;

    private Long slotId;

    private Long exposurePv;

    private Long clickPv;

    private String speedType;

    private String planStatus;

    private String progress;

    private String date;

    private String[] hours;

    private String switchStatus;

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Long exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Long getClickPv() {
        return clickPv;
    }

    public void setClickPv(Long clickPv) {
        this.clickPv = clickPv;
    }

    public String getSpeedType() {
        return speedType;
    }

    public void setSpeedType(String speedType) {
        this.speedType = speedType;
    }

    public String getPlanStatus() {
        return planStatus;
    }

    public void setPlanStatus(String planStatus) {
        this.planStatus = planStatus;
    }

    public String getProgress() {
        return progress;
    }

    public void setProgress(String progress) {
        this.progress = progress;
    }

    public String getDate() {
        return date;
    }

    public void setDate(String date) {
        this.date = date;
    }

    public String[] getHours() {
        return hours;
    }

    public void setHours(String[] hours) {
        this.hours = hours;
    }

    public String getSwitchStatus() {
        return switchStatus;
    }

    public void setSwitchStatus(String switchStatus) {
        this.switchStatus = switchStatus;
    }
}

==> tuia-advert-center-api-2.4.47-sources.jar: cn/com/duiba/tuia/core/api/dto/flowback/MsgDataFlowbackPlanDTO.java <==
package cn.com.duiba.tuia.core.api.dto.flowback;

import java.io.Serializable;
import java.util.List;

public class MsgDataFlowbackPlanDTO implements Serializable {
    private static final long serialVersionUID = -2902179719198671806L;
    private Long planId;

    private Long advertId;

    private Long appId;

    private String appKey;

    private Long slotId;

    private Long exposurePv;

    private Long clickPv;

    private String speedType;

    private String planStatus;

    private String progress;

    private String date;

    private String[] hours;

    private String switchStatus;

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Long exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Long getClickPv() {
        return clickPv;
    }

    public void setClickPv(Long clickPv) {
        this.clickPv = clickPv;
    }

    public String getSpeedType() {
        return speedType;
    }

    public void setSpeedType(String speedType) {
        this.speedType = speedType;
    }

    public String getPlanStatus() {
        return planStatus;
    }

    public void setPlanStatus(String planStatus) {
        this.planStatus = planStatus;
    }

    public String getProgress() {
        return progress;
    }

    public void setProgress(String progress) {
        this.progress = progress;
    }

    public String getDate() {
        return date;
    }

    public void setDate(String date) {
        this.date = date;
    }

    public String[] getHours() {
        return hours;
    }

    public void setHours(String[] hours) {
        this.hours = hours;
    }

    public String getSwitchStatus() {
        return switchStatus;
    }

    public void setSwitchStatus(String switchStatus) {
        this.switchStatus = switchStatus;
    }
}
